@@ -35,7 +35,10 @@ static void fire_watchers(pTHX_ IV idx, SV *new_val);
 static OP* pp_slot_get(pTHX) {
     dSP;
     IV idx = PL_op->op_targ;
-    PUSHs(g_slots[idx]);  /* Stack already extended by call */
+#ifdef DEBUGGING
+    EXTEND(SP, 1);  /* Ensure stack space - only needed for DEBUGGING builds */
+#endif
+    PUSHs(g_slots[idx]);
     RETURN;
 }
 
